import { useMemo, lazy } from 'react';
/**
 * Async component loading for use with Dashboard.
 *
 * Should be used with component wrapped in `React.Suspense`
 *
 * @example
 * ```
 * const AsyncHeader = () => {
 *  const Header = useAsyncComponent('Header');
 *
 *  return <Header>Hello world!</Header>
 * }
 *
 * ...
 *
 * <React.Suspense fallback={<Loader active />}>
 *   <AsyncHeader />
 * </React.Suspense>
 * ```
 */
export var useWidget = function (type) {
    return useMemo(function () {
        switch (type) {
            case 'StatisticTeaching':
                return lazy(function () {
                    return import('./Statistic').then(function (module) { return ({
                        default: module.StatisticsTeachingController,
                    }); });
                });
            case 'StatisticConversion':
                return lazy(function () {
                    return import('./Statistic').then(function (module) { return ({
                        default: module.StatisticConversionSwitcher,
                    }); });
                });
            case 'ConversionSessions':
                return lazy(function () {
                    return import('./ConversionSessions').then(function (module) { return ({
                        default: module.ConversionSessions,
                    }); });
                });
            case 'TeachingSessions':
                return lazy(function () {
                    return import('./TeachingSessions').then(function (module) { return ({
                        default: module.TeachingSessions,
                    }); });
                });
            case 'WelcomeTeaching':
                return lazy(function () {
                    return import('./Welcome').then(function (module) { return ({
                        default: module.WelcomeTeaching,
                    }); });
                });
            case 'WelcomeConversion':
                return lazy(function () {
                    return import('./Welcome').then(function (module) { return ({
                        default: module.WelcomeConversion,
                    }); });
                });
            case 'TopTeachingContributors':
                return lazy(function () {
                    return import('./TopContributors').then(function (module) { return ({
                        default: module.TopTeachingContributors,
                    }); });
                });
            case 'TopConverters':
                return lazy(function () {
                    return import('./TopContributors').then(function (module) { return ({
                        default: module.TopConverters,
                    }); });
                });
            case 'YourKis':
                return lazy(function () {
                    return import('./YourKis').then(function (module) { return ({
                        default: module.YourKis,
                    }); });
                });
            case 'Demo':
                return lazy(function () {
                    return import('./Demo').then(function (module) { return ({ default: module.Demo }); });
                });
            default:
                if (type) {
                    console.warn("Async component '" + type + "' not supported");
                }
                return lazy(function () { return import('../../elements/Flex/Box'); });
        }
    }, [type]);
};
export default useWidget;
